Skip to contents

Runs `targets::tar_load_globals` then `targets::tar_load_everything` to save you the drudgery of typing those thing out again and again and again and again and again et cetera ad nauseum.

Usage

tl()

Value

Nothing

Examples

if (FALSE) { # \dontrun{
tl()
} # }