Find all targets that a given target depends on, either directly or indirectly. This is useful for understanding the dependencies and requirements of a target.
Value
Character vector of upstream target names (excluding the target itself). Returns an empty character vector if there are no upstream targets (i.e., the target has no dependencies).
Details
This function is the inverse of [tar_downstream()]. While `tar_downstream()` shows what depends on a target, `tar_upstream()` shows what a target depends on.
This function requires the `igraph` package, which is listed in Imports. It queries the current targets pipeline via `targets::tar_network()` and traverses the dependency graph to find all targets that the specified target depends on.